@@ -290,6 +290,28 @@ class XPtrTorchIntArrayRef : public XPtrTorch {
   XPtrTorchIntArrayRef(const XPtrTorchIntArrayRef& x)
       : XPtrTorch(x.get_shared()){};
   explicit XPtrTorchIntArrayRef(SEXP x);
+  operator SEXP () const;
+};
+
+class XPtrTorchSymIntArrayRef : public XPtrTorch {
+public:
+  XPtrTorchSymIntArrayRef() : XPtrTorch{NULL} {};
+  XPtrTorchSymIntArrayRef(void* x) : XPtrTorch(x, delete_vector_int64_t) {}
+  explicit XPtrTorchSymIntArrayRef(std::shared_ptr<void> x) : XPtrTorch(x){};
+  XPtrTorchSymIntArrayRef(const XPtrTorchSymIntArrayRef& x)
+    : XPtrTorch(x.get_shared()){};
+  explicit XPtrTorchSymIntArrayRef(SEXP x);
+  // operator SEXP () const;
+};
+
+class XPtrTorchSymInt : public XPtrTorch {
+public:
+  XPtrTorchSymInt() : XPtrTorch{NULL} {};
+  XPtrTorchSymInt(void* x) : XPtrTorch(x, delete_vector_int64_t) {}
+  explicit XPtrTorchSymInt(std::shared_ptr<void> x) : XPtrTorch(x){};
+  XPtrTorchSymInt(const XPtrTorchSymInt& x)
+    : XPtrTorch(x.get_shared()){};
+  explicit XPtrTorchSymInt(SEXP x);
   // operator SEXP () const;
 };
 
@@ -394,8 +416,9 @@ class XPtrTorchstring : public XPtrTorch {
   XPtrTorchstring(SEXP x);
   XPtrTorchstring(const XPtrTorchstring& x) : XPtrTorch(x.get_shared()){};
   XPtrTorchstring(std::string x)
-      : XPtrTorchstring(fixme_new_string(x.c_str())){};
+      : XPtrTorchstring(fixme_new_string(x.c_str(), x.size())){};
   operator SEXP() const;
+  operator std::string() const;
 };
 
 class XPtrTorchstring_view : public XPtrTorch {
